summaryrefslogtreecommitdiff
path: root/files.c
diff options
context:
space:
mode:
Diffstat (limited to 'files.c')
-rw-r--r--files.c35
1 files changed, 30 insertions, 5 deletions
diff --git a/files.c b/files.c
index 74d3cea..abfa9c0 100644
--- a/files.c
+++ b/files.c
@@ -608,6 +608,18 @@ int set_destinations(Options *op, Package *p)
path = "";
break;
+ case FILE_TYPE_ENCODEAPI_LIB:
+ case FILE_TYPE_ENCODEAPI_SYMLINK:
+ if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
+ prefix = op->compat32_prefix;
+ dir = op->compat32_libdir;
+ } else {
+ prefix = op->opengl_prefix;
+ dir = op->opengl_libdir;
+ }
+ path = "";
+ break;
+
case FILE_TYPE_OPENGL_HEADER:
prefix = op->opengl_prefix;
dir = op->opengl_incdir;
@@ -1146,12 +1158,13 @@ int confirm_path(Options *op, const char *path)
/*
* mkdir_recursive() - create the path specified, also creating parent
* directories as needed; this is equivalent to `mkdir -p`
*/
-int mkdir_recursive(Options *op, const char *path, const mode_t mode)
+int mkdir_with_log(Options *op, const char *path, const mode_t mode, int log)
{
char *c, *tmp, ch, *list, *tmplist;
@@ -1185,7 +1198,7 @@ int mkdir_recursive(Options *op, const char *path, const mode_t mode)
} while (*c);
/* Log any created directories */
- if (list) {
+ if (log && list) {
log_mkdir(op, list);
}
@@ -1193,6 +1206,18 @@ int mkdir_recursive(Options *op, const char *path, const mode_t mode)
free(tmp);
return TRUE;
+} /* mkdir_with_log */
+
+
+
+/*
+ * mkdir_recursive() - Wrap mkdir_with_log() to create the path specified
+ * with any needed parent directories.
+ */
+
+int mkdir_recursive(Options *op, const char *path, const mode_t mode)
+{
+ return mkdir_with_log(op, path, mode, TRUE);
} /* mkdir_recursive() */
@@ -1146,12 +1158,13 @@ int confirm_path(Options *op, const char *path)
dir = op->opengl_incdir;
-/*
- * mkdir_recursive() - create the path specified, also creating parent
- * directories as needed; this is equivalent to `mkdir -p`
+/*
+ * mkdir_with_log() - create the path specified, also creating parent
+ * directories as needed; this is equivalent to `mkdir -p`. Log created
+ * directories if the "log" parameter is set.
*/